@@ -116,12 +116,13 @@ score.lm <- function(x,p=coef(x),data,indiv=FALSE,
   A <- as.vector(r)/sigma2 
   S <- apply(X,2,function(x) x*A)
   if (!indiv) return(colSums(S))
+  attributes(S)$bread <- vcov(x)
   return(S)
 }
 
 ##' @S3method score glm
 score.glm <- function(x,p=coef(x),data,indiv=FALSE,
-                      y,X,link,dispersion,offset=NULL,...) {
+                      y,X,link,dispersion,offset=NULL,weight,...) {
 
   response <- all.vars(formula(x))[1]
   if (inherits(x,"glm")) {
@@ -169,7 +170,14 @@ score.glm <- function(x,p=coef(x),data,indiv=FALSE,
   r <- y-pi
   A <- as.vector(h(Xbeta)*r)/a.phi 
   S <- apply(X,2,function(x) x*A)
+  if (!is.null(x$weight) || !missing(weight)) {
+      if (missing(weight)) weight <- x$weight
+      S <- apply(S,2,function(x) x*weight)
+  }
   if (!indiv) return(colSums(S))
+  attributes(S)$bread <- vcov(x)
+  if (x$family$family=="quasi" && x$family$link=="identity" && x$family$varfun=="constant")
+      attributes(S)$bread <- Inverse(information.glm(x))
   return(S)
 }
 
@@ -207,8 +215,17 @@ logL.glm <- function(x,p=pars.glm(x),indiv=FALSE,...) {
   structure(loglik,nobs=n,df=length(p),class="logLik")
 }
 
+##' @S3method iid glm
+iid.glm <- function(x,...) {
+    ## if (x$family$family=="quasi" && x$family$link=="identity" && x$family$varfun=="constant") {
+    ##     return(iid.default(x,information.glm,...))
+    ## }
+    iid.default(x,...)
+}
+
+
 hessian.glm <- function(x,p=coef(x),...) {  
-  numDeriv::jacobian(function(theta) score.glm(x,p=theta,...),p)
+  numDeriv::jacobian(function(theta) score.glm(x,p=theta,indiv=FALSE,...),p)
 }
 
 ##' @S3method information glm
