@@ -4,8 +4,8 @@
 
 ##' @S3method pars default
 pars.default <- function(x,...) {
-  if (!is.null(x$opt$est))
-    return(x$opt$est)
+  if (!is.null(x$opt$estimate))
+    return(x$opt$estimate)
   if (!is.null(x$coef))
     return(x$coef)
   return(coef(x))
@@ -22,7 +22,7 @@ pars.default <- function(x,...) {
 ###{{{ pars.lvm
 
 ##' @S3method pars lvm
-pars.lvm <- function(x, A, P, v,...) {
+pars.lvm <- function(x, A, P, v, e, ...) {
   parres <- A[index(x)$M1==1]
   diagcorfree <- diag(P)[diag(index(x)$P1)==1]
   parres <- c(parres, diagcorfree)
@@ -35,10 +35,13 @@ pars.lvm <- function(x, A, P, v,...) {
       }
     }
   if (length(parres)>0)
-  names(parres) <- paste("p",1:length(parres),sep="")
+  names(parres) <- paste("p",seq_len(length(parres)),sep="")
   if (!missing(v)) {
     parres <- c( v[which(index(x)$v1==1)], parres)
   }
+  if (!missing(e)) {
+    parres <- c( parres, e[which(index(x)$e1==1)] )
+  }
   return(parres)        
 }
 
